"""Tests for graphql.validation"""

from pytest import register_assert_rewrite

register_assert_rewrite("tests.validation.harness")
